/*!
 * Ext JS Library 3.3.1
 * Copyright(c) 2006-2010 Sencha Inc.
 * licensing@sencha.com
 * http://www.sencha.com/license
 */
Ext.onReady(function(){

	// Enable button tooltips
	Ext.QuickTips.init();
	
	// Disable default context menu
	Ext.getBody().on("contextmenu", Ext.emptyFn, null, {preventDefault: true});

	var reader = new Ext.data.ArrayReader({}, [
		{name: 'class'},
		{name: 'name'},
		{name: 'delay', type: 'int' },
		{name: 'frames', type: 'int' },
		{name: 'repeat'}
	]);

	var store = new Ext.data.Store({
		id:'theStore',
		reader: reader,
		data: animationArray,
		sortInfo: {
			field: 'delay',
			direction: 'ASC'
		}
	});
	
	function context_menu_items(name, type) {
		items = []
		items.push(new Ext.menu.Item({
			text: 'Play',
			handler : function(extEventObject, t) {
				window.location = 'skp:on_play@' + name;
			}
		}));
		items.push(new Ext.menu.Item({
			text: 'Edit',
			handler : function(extEventObject, t) {
				window.location = 'skp:on_edit@' + name;
			}
		}));
		if (type != "SU_Shadow_Animation") {
			items.push(new Ext.menu.Item({
				text: 'Add/Remove',
				handler : function(extEventObject, t) {
					window.location = 'skp:on_add_remove@' + name;
				}
			}));
		}
		items.push(new Ext.menu.Item({
			text: 'Delete',
			handler : function(extEventObject, t) {
				var r=confirm("Delete animation \"" + name + "\"?");
				if (r===true) {
					window.location = 'skp:on_delete@' + name;
				}
			}
		}));
		return items;
	}

	var gridPanel = new Ext.grid.EditorGridPanel({
		store: store,
		multiSelect: true,
		emptyText: 'No animations to display',
		reserveScrollOffset: false,
		width: 300,
		height: 500,

		listeners: {
			rowclick: function (grid, rowIndex, extEventObject) {
				var aname = grid.getStore().getAt(rowIndex).data["name"];
				var jscript = "window.location = 'skp:on_selected@" + aname + "'";
				setTimeout(jscript, 100);
			},
			validateedit: function (e) {
				// Name cannot include '|'
				if (e.field == 'name' && e.value.indexOf('|') != -1) {
					alert('Name cannot include the vertical bar character');
					return false;
				}
			},
			afterEdit: function (e) {
				selectedAnimation = e.record.get('name');
				if (e.field == 'name') {
					selectedAnimation = e.originalValue;
				}
				window.location = 'skp:on_edit_common@' + selectedAnimation + '|' + e.field + '|' + e.value;
			},
			rowContextMenu: function (grid, rowIndex, extEventObject) {
				var xy = extEventObject.getXY();
				var name = grid.getStore().getAt(rowIndex).data["name"];
				var type = grid.getStore().getAt(rowIndex).data["class"];
				this.contextMenu = new Ext.menu.Menu({
					items: context_menu_items(name, type)
				});
				this.contextMenu.showAt(xy);
				window.location = 'skp:on_selected@' + grid.getStore().getAt(rowIndex).data["name"];
			}
		},

		tbar:[{
			text: 'New...',
			tooltip:'New animation',
			menu: new Ext.menu.Menu({
				width: 280,
				items: [{
					text: 'Key Frame Animation',
					tooltip:'Create a new key frame animation',
					handler : function(extEventObject, t) {
						window.location = 'skp:on_create_key_frame@';
					}
				},{
					text: 'Polyline Path Animation',
					tooltip:'Create a new polyline path animation',
					handler : function(extEventObject, t) {
						window.location = 'skp:on_create_polyline_path@';
					}
				},{
					text: 'Arc/Circle Path Animation',
					tooltip:'Create a new arc or circle path animation',
					handler : function(extEventObject, t) {
						window.location = 'skp:on_create_arc_circle_path@';
					}
				},{
					text: 'Spiral Path Animation',
					tooltip:'Create a new spiral path animation',
					handler : function(extEventObject, t) {
						window.location = 'skp:on_create_spiral_path@';
					}
				},{
					text: 'Table-driven Animation',
					tooltip:'Create a new table-driven animation',
					handler : function(extEventObject, t) {
						window.location = 'skp:on_create_table_driven@';
					}
				},{
					text: 'Shadow Animation',
					tooltip:'Create a new shadow animation',
					handler : function(extEventObject, t) {
						window.location = 'skp:on_create_shadow@';
					}
				}]
			})
		}, '-', {
			text:'Play',
			tooltip:'Play Animation',
			handler : function() {
				window.location = 'skp:on_play@';
			}
		},'-',{
			text:'Refresh',
			tooltip:'Refresh this dialog',
			handler : function() {
				window.location = 'skp:on_refresh@';
			}
		},'-',{
			text:'Tools...',
			tooltip:'Animation tools',
			menu: new Ext.menu.Menu({
				width: 280,
				items: [{
					text: 'Create a layer animation',
					tooltip:'Create an animation that makes layers visible one-by-one',
					handler : function(extEventObject, t) {
						window.location = 'skp:on_layer_animation@';
					}
				},{
					text: 'Name all groups/components',
					tooltip:'Generate a name for all unnamed groups/components in the model',
					handler : function(extEventObject, t) {
						window.location = 'skp:on_name_all_groups@';
					}
				},{
					text: 'Distribute groups/components to layers',
					tooltip:'Put each group/component on a named layer',
					handler : function(extEventObject, t) {
						window.location = 'skp:on_distribute_groups_to_layers@';
					}
				},{
					text: 'Make Scenes',
					tooltip:'Make a scene (page) of each frame in the animation',
					handler : function(extEventObject, t) {
						window.location = 'skp:on_make_scenes@';
					}
				},{
					text: 'Export Camera Path',
					tooltip:'Export camera eye, target and up parameters of each frame in the animation to a file',
					handler : function(extEventObject, t) {
						window.location = 'skp:on_export_camera_path@';
					}
/*
				},{
					text: 'Make Image Files',
					tooltip:'Create an image file for each frame (Not implemented)',
					handler : function(extEventObject, t) {
						alert('Not implemented');
					}
				},{
					text: 'Render All Frames',
					tooltip:'Render each frame in the animation (Not implemented)',
					handler : function(extEventObject, t) {
						alert('Not implemented');
					}
*/
				},{
					text: 'Enter License Key',
					handler : function() {
						window.location = 'skp:on_license_key@';
					}
				},{
					text: 'About SU Animate! V4',
					handler : function() {
						window.location = 'skp:on_help@';
					}
				}]
			})
		}],

		columns: [{
			header: 'Name',
			width: 90,
			dataIndex: 'name',
			sortable: true,
			renderer: function(value, metaData, record, rowIndex, colIndex, store) {
				//if (record.data["class"] == "SU_Path_Animation") {
				//	return '<img src="extjs/resources/images/path.gif" /> ' + record.data["name"];
				//} else {
					return record.data["name"];
				//}
			},
			editor: new Ext.form.TextField({
				allowBlank: false
			})
		},{
			header: 'Delay',
			width: 50,
			dataIndex: 'delay',
			sortable: true,
			editor: new Ext.form.NumberField({
				allowBlank: false,
				allowNegative: false
			})
		},{
			header: 'Frames',
			width: 50,
			dataIndex: 'frames',
			sortable: true,
			editor: new Ext.form.NumberField({
				allowBlank: false,
				allowNegative: false
			})
		}
		,{
			header: 'Repeat',
			width: 50,
			dataIndex: 'repeat',
			sortable: false,
			renderer: function(value, metaData, record, rowIndex, colIndex, store) {
				aname = record.data["name"];
					retString = '<input name=\"' + aname + '\" type="Checkbox" onclick="toggleRepeat(\'' + aname + '\');">';
				if (record.data["repeat"] != "No") {
					retString = '<input name=\"' + aname + '\" type="Checkbox" checked="checked" onclick="toggleRepeat(\'' + aname + '\');">';
				}
				return retString;
			}
		}]
	});

	// Putting the panel into a Viewport gets rid of the SU WebDialog scrollbar (on PC).
	new Ext.Viewport({
		title: 'Animations',
		layout: 'fit',
		items: [ 
			gridPanel 
		]
	});
});