Ext.onReady(function(){

	// Enable button tooltips
	Ext.QuickTips.init();

	// Disable default context menu
	Ext.getBody().on("contextmenu", Ext.emptyFn, null, {preventDefault: true});

	// Spacers for panel layout
	Ext.ns('Ext.ux.form');
	Ext.ux.form.Spacer = Ext.extend(Ext.BoxComponent, {
	  height: 22,
	  autoEl: 'div' 
	});
	Ext.reg('spacer', Ext.ux.form.Spacer);
	Ext.ux.form.SpacerSmall = Ext.extend(Ext.BoxComponent, {
	  height: 4,
	  autoEl: 'div' 
	});
	Ext.reg('spacer_small', Ext.ux.form.SpacerSmall);

	// Grid of KeyFrames
	var reader = new Ext.data.ArrayReader({}, [
		{name: 'name'}
	]);

	var store = new Ext.data.Store({
		id:'theStore',
		reader: reader,
		data: keyFrameArray
	});

	var gridPanel = new Ext.grid.EditorGridPanel({
		renderTo: Ext.getBody(),
		title: operationString,
		store: store,
		multiSelect: false,
		reserveScrollOffset: false,
		width: 220,
		height: 200,
		region: 'north',

		enableDragDrop : true,
		ddGroup : 'mygrid-dd',
		ddText : 'Move up or down',
		sm: new Ext.grid.RowSelectionModel({  
			singleSelect:true,
			listeners: {
				beforerowselect: function(sm,i,ke,row){
					gridPanel.ddText = row.data.name;
			}}
		}),

		listeners: {
			rowclick: function (grid, rowIndex, extEventObject) {
				window.location = 'skp:on_selected@' + grid.getStore().getAt(rowIndex).data["name"];
			},
			validateedit: function (e) {
				// Name cannot include '|'
				if (e.field == 'name' && e.value.indexOf('|') != -1) {
					alert('Name cannot include the vertical bar character');
					return false;
				}
			},
			afterEdit: function (e) {
				selectedAnimation = e.record.get('name');
				if (e.field == 'name') {
					selectedAnimation = e.originalValue;
				}
				window.location = 'skp:on_edit_common@' + selectedAnimation + '|' + e.field + '|' + e.value;
			},
			rowContextMenu: function (grid, rowIndex, extEventObject) {
				var xy = extEventObject.getXY();
				var name = grid.getStore().getAt(rowIndex).data["name"];
				this.contextMenu = new Ext.menu.Menu({
					items: [{
						text: 'Set view',
						tooltip:'Set active view to this frame',
						handler : function(extEventObject, t) {
							window.location = 'skp:on_set_key_frame@' + name;
						}
					},{
						text: 'Add/update sound',
						tooltip:'Play a sound file when this frame is made active',
						handler : function(extEventObject, t) {
							window.location = 'skp:on_set_sound_file@' + name;
						}
					},{
						text: 'Remove sound',
						tooltip:'Remove the sound associated with this frame',
						handler : function(extEventObject, t) {
							window.location = 'skp:on_remove_sound_file@' + name;
						}
					},{
						text:'Delete',
						tooltip:'Delete this frame',
						handler : function(extEventObject, t) {
							var r=confirm("Delete frame \"" + name + "\"?");
							if (r===true) {
								window.location = 'skp:on_remove_key_frame@' + name;
							}
						}
					}]
				});
				this.contextMenu.showAt(xy);
			}
		},

		tbar:[{
			text: 'Capture',
			handler : function() {
				window.location = 'skp:on_add_key_frame@';
			}
		},'-',{
			text:'?',
			tooltip:'Quick help',
			handler : function() {
				message = 
					'Use the "Capture" button to capture the current \n' +
					'entities, layer and camera information in a key frame; \n' + 
					'then move entities or turn layers on/off or adjust \n' +
					'the camera, and capture more key frames. \n' + 
					'\n' + 
					'Right-click a key frame from the list, and use "Set view" \n' +
					'to set the current view, layer and camera settings from \n' +
					'the information captured in that key frame. \n' +
					'\n' + 
					'Key frames are ordered; reorder using drag-and-drop. \n' +
					'\n' + 
					'"Save" creates a new key frame animation which will \n' +
					'transition between the key frames. Increase the "Frames" \n' +
					'count to transition more smoothly. \n';
				alert(message);
			}
		}],

		columns: [{
			// No header: 'Name',
			dataIndex: 'name',
			sortable: false,
			editor: new Ext.form.TextField({
				allowBlank: false
			})
		}]
	});

	// Need renderTo above for this to load.
	var ddrow = new Ext.dd.DropTarget(gridPanel.getView().mainBody, {
		ddGroup : 'mygrid-dd',
		notifyDrop : function(dd, e, data){
			var sm = gridPanel.getSelectionModel();
			var rows = sm.getSelections();
			var cindex = dd.getDragData(e).rowIndex;
			if (sm.hasSelection()) {
				for (i = 0; i < rows.length; i++) {
					store.remove(store.getById(rows[i].id));
					store.insert(cindex,rows[i]);
					window.location = 'skp:on_dragdrop_key_frame@' + rows[i].data["name"] + '|' + cindex;
				}
				sm.selectRecords(rows);
			}  
		}
	});

	var formPanel = new Ext.FormPanel({
		labelWidth: 50, 
		frame:true,
		width: 220,
		region: 'center',
		items: [
			new Ext.form.NumberField({
				fieldLabel: 'Frames',
				width: 120,
				value: initialFramesValue,
				minValue: 1,
				listeners: {
					change: function (e) {
						window.location = 'skp:on_frames@' + e.value;
					}		
				}
			}),
			{
				xtype: 'spacer_small'
			},
			new Ext.Button({
				text: 'Reverse',
				align: 'left',
				handler : function() {
					window.location = 'skp:on_reverse@';
				}
			}),
			{
				xtype: 'spacer_small'
			},
			{
				xtype: 'checkbox',
				boxLabel: 'Animates the Camera',
				hideLabel: true,
				checked: animates_camera,
				handler : function() {
					window.location = 'skp:on_animates_camera@';
				}
			}
		],

		buttons: [{
			text: 'Save',
			handler : function() {
				// Report order of key frames
				//var frames = "";
				//store.each(function(record)  
				//{  
				//	record.fields.each(function(field) 
				//	{ 
				//		frames += record.get(field.name) + '|';	   
				//	}); 
				//}, this);
				window.location = 'skp:on_save@';
			}
		},{
			text: 'Cancel',
			handler : function() {
				window.location = 'skp:on_cancel@';
			}
		}]
	});

	// Putting the panel into a Viewport gets rid of the SU WebDialog scrollbar (on PC).
	new Ext.Viewport({
		title: 'Animations',
		layout: 'border',
		items: [ 
			gridPanel,
			formPanel 
		]
	});
});